@@ -613,31 +613,51 @@ async def _speech_to_text_internal(
         if stt_config.get('base_url') and ("127.0.0.1" in stt_config['base_url'] or "localhost" in stt_config['base_url']):
             provider = "whisper-local"
         
-        # Validate format for provider
-        export_format = validate_audio_format(STT_AUDIO_FORMAT, provider, "stt")
+        # Check if we can skip conversion for local whisper
+        skip_conversion = False
+        if provider == "whisper-local":
+            # Check if whisper is truly local (not SSH-forwarded)
+            from voice_mode.utils.services.common import check_service_status
+            from voice_mode.config import WHISPER_PORT
+            status, _ = check_service_status(WHISPER_PORT)
+            if status == "local":
+                skip_conversion = True
+                logger.info("Detected truly local whisper - skipping audio conversion, using WAV directly")
         
-        # Convert WAV to target format for upload
-        logger.debug(f"Converting WAV to {export_format.upper()} for upload...")
-        try:
-            audio = AudioSegment.from_wav(wav_file)
-            logger.debug(f"Audio loaded - Duration: {len(audio)}ms, Channels: {audio.channels}, Frame rate: {audio.frame_rate}")
+        if skip_conversion:
+            # Use WAV directly for local whisper
+            upload_file = wav_file
+            export_format = "wav"
+            logger.debug("Using WAV file directly for local whisper upload")
+        else:
+            # Validate format for provider
+            export_format = validate_audio_format(STT_AUDIO_FORMAT, provider, "stt")
             
-            # Get export parameters for the format
-            export_params = get_format_export_params(export_format)
-            
-            with tempfile.NamedTemporaryFile(suffix=f'.{export_format}', delete=False) as export_file_obj:
-                export_file = export_file_obj.name
-                audio.export(export_file, **export_params)
-                upload_file = export_file
-                logger.debug(f"{export_format.upper()} created for STT upload: {upload_file}")
-        except Exception as e:
-            if "ffmpeg" in str(e).lower() or "avconv" in str(e).lower():
-                logger.error(f"Audio conversion failed - FFmpeg may not be installed: {e}")
-                from voice_mode.utils.ffmpeg_check import get_install_instructions
-                logger.error(f"\n{get_install_instructions()}")
-                raise RuntimeError("FFmpeg is required but not found. Please install FFmpeg and try again.") from e
-            else:
-                raise
+            # Convert WAV to target format for upload
+            logger.debug(f"Converting WAV to {export_format.upper()} for upload...")
+            conversion_start = time.perf_counter()
+            try:
+                audio = AudioSegment.from_wav(wav_file)
+                logger.debug(f"Audio loaded - Duration: {len(audio)}ms, Channels: {audio.channels}, Frame rate: {audio.frame_rate}")
+                
+                # Get export parameters for the format
+                export_params = get_format_export_params(export_format)
+                
+                with tempfile.NamedTemporaryFile(suffix=f'.{export_format}', delete=False) as export_file_obj:
+                    export_file = export_file_obj.name
+                    audio.export(export_file, **export_params)
+                    upload_file = export_file
+                    conversion_time = time.perf_counter() - conversion_start
+                    logger.info(f"Audio conversion: WAV → {export_format.upper()} took {conversion_time:.3f}s")
+                    logger.debug(f"{export_format.upper()} created for STT upload: {upload_file}")
+            except Exception as e:
+                if "ffmpeg" in str(e).lower() or "avconv" in str(e).lower():
+                    logger.error(f"Audio conversion failed - FFmpeg may not be installed: {e}")
+                    from voice_mode.utils.ffmpeg_check import get_install_instructions
+                    logger.error(f"\n{get_install_instructions()}")
+                    raise RuntimeError("FFmpeg is required but not found. Please install FFmpeg and try again.") from e
+                else:
+                    raise
         
         # Save debug file for upload version
         if DEBUG:
@@ -764,7 +784,9 @@ async def play_audio_feedback(
     style: str = "whisper", 
     feedback_type: Optional[str] = None,
     voice: str = "nova",
-    model: str = "gpt-4o-mini-tts"
+    model: str = "gpt-4o-mini-tts",
+    pip_leading_silence: Optional[float] = None,
+    pip_trailing_silence: Optional[float] = None
 ) -> None:
     """Play an audio feedback chime
     
@@ -776,6 +798,8 @@ async def play_audio_feedback(
         feedback_type: Kept for compatibility, not used
         voice: Kept for compatibility, not used
         model: Kept for compatibility, not used
+        pip_leading_silence: Optional override for leading silence duration
+        pip_trailing_silence: Optional override for trailing silence duration
     """
     # Use parameter override if provided, otherwise use global setting
     if enabled is False:
@@ -790,11 +814,17 @@ async def play_audio_feedback(
         return
     
     try:
-        # Play appropriate chime
+        # Play appropriate chime with optional delay overrides
         if text == "listening":
-            await play_chime_start()
+            await play_chime_start(
+                leading_silence=pip_leading_silence,
+                trailing_silence=pip_trailing_silence
+            )
         elif text == "finished":
-            await play_chime_end()
+            await play_chime_end(
+                leading_silence=pip_leading_silence,
+                trailing_silence=pip_trailing_silence
+            )
     except Exception as e:
         logger.debug(f"Audio feedback failed: {e}")
         # Don't interrupt the main flow if feedback fails
@@ -1293,8 +1323,10 @@ async def converse(
     audio_format: Optional[str] = None,
     disable_silence_detection: Union[bool, str] = False,
     speed: Optional[float] = None,
-    vad_aggressiveness: Optional[int] = None,
-    skip_tts: Optional[Union[bool, str]] = None
+    vad_aggressiveness: Optional[Union[int, str]] = None,
+    skip_tts: Optional[Union[bool, str]] = None,
+    pip_leading_silence: Optional[float] = None,
+    pip_trailing_silence: Optional[float] = None
 ) -> str:
     """Have a voice conversation - speak a message and optionally listen for response.
     
@@ -1319,14 +1351,13 @@ async def converse(
         message: The message to speak
         wait_for_response: Whether to listen for a response after speaking (default: True)
         listen_duration: How long to listen for response in seconds (default: 120.0)
-                         Recommended durations based on expected response:
-                         - Simple yes/no questions: 10 seconds
-                         - Normal conversational responses: 30 seconds  
-                         - Open-ended questions: 60 seconds
-                         - Detailed explanations: 120 seconds (default)
-                         - Stories or long explanations: 300 seconds
-                         Always err on the side of longer duration - it's better to have 
-                         silence at the end than to cut off the user mid-sentence.
+                         The tool handles silence detection well and uses a sensible default.
+                         It's unusual to need to set the duration - only override if you have 
+                         specific requirements such as:
+                         - Silence detection is disabled and you need a specific timeout
+                         - You know the response will be exceptionally long (>120s)
+                         - You're in a special mode that requires different timing
+                         In most cases, just let the default and silence detection handle it.
         min_listen_duration: Minimum time to record before silence detection can stop (default: 2.0)
                              Useful for preventing premature cutoffs when users need thinking time.
                              Examples:
@@ -1371,6 +1402,10 @@ async def converse(
                   When False: Always use TTS regardless of environment setting
                   When None: Follow VOICEMODE_SKIP_TTS environment variable
                   Useful for rapid development iterations or when voice isn't needed
+        pip_leading_silence: Override leading silence before chimes (default: None uses VOICEMODE_PIP_LEADING_SILENCE env var)
+                             Time in seconds to add before the chime starts (e.g., 1.0 for Bluetooth devices)
+        pip_trailing_silence: Override trailing silence after chimes (default: None uses VOICEMODE_PIP_TRAILING_SILENCE env var)
+                              Time in seconds to add after the chime ends (e.g., 0.5 to prevent cutoff)
         If wait_for_response is False: Confirmation that message was spoken
         If wait_for_response is True: The voice response received (or error/timeout message)
     
@@ -1459,6 +1494,15 @@ async def converse(
     if skip_tts is not None and isinstance(skip_tts, str):
         skip_tts = skip_tts.lower() in ('true', '1', 'yes', 'on')
     
+    # Convert vad_aggressiveness to integer if provided as string
+    if vad_aggressiveness is not None and isinstance(vad_aggressiveness, str):
+        try:
+            vad_aggressiveness = int(vad_aggressiveness)
+            # Validation will happen later in the function
+        except ValueError:
+            logger.warning(f"Invalid VAD aggressiveness value '{vad_aggressiveness}', using default")
+            vad_aggressiveness = None
+    
     # Determine whether to skip TTS
     if skip_tts is not None:
         # Parameter explicitly set, use it
@@ -1777,7 +1821,14 @@ async def converse(
                     await asyncio.sleep(0.5)
                     
                     # Play "listening" feedback sound
-                    await play_audio_feedback("listening", openai_clients, audio_feedback, audio_feedback_style or "whisper")
+                    await play_audio_feedback(
+                        "listening", 
+                        openai_clients, 
+                        audio_feedback, 
+                        audio_feedback_style or "whisper",
+                        pip_leading_silence=pip_leading_silence,
+                        pip_trailing_silence=pip_trailing_silence
+                    )
                     
                     # Record response
                     logger.info(f"🎤 Listening for {listen_duration} seconds...")
@@ -1801,7 +1852,14 @@ async def converse(
                         })
                     
                     # Play "finished" feedback sound
-                    await play_audio_feedback("finished", openai_clients, audio_feedback, audio_feedback_style or "whisper")
+                    await play_audio_feedback(
+                        "finished", 
+                        openai_clients, 
+                        audio_feedback, 
+                        audio_feedback_style or "whisper",
+                        pip_leading_silence=pip_leading_silence,
+                        pip_trailing_silence=pip_trailing_silence
+                    )
                     
                     # Mark the end of recording - this is when user expects response to start
                     user_done_time = time.perf_counter()
